import { BehaviorSubject, defer, Subject } from 'rxjs';
import { finalize, takeUntil } from 'rxjs/operators';
import * as i1 from '@angular/animations';
import { useAnimation, animation, animate, style, AUTO_STYLE } from '@angular/animations';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Component, Inject, Input, ViewChild, ElementRef, Directive, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

function getArray(param) {
    let array = [];
    if (param) {
        if (Array.isArray(param)) {
            array = param;
        }
        else {
            array = [param];
        }
    }
    return array;
}
let loadingCount = 0;
const isLoadingFullPage = new BehaviorSubject(false);
function updateFullPageLoading() {
    isLoadingFullPage.next(loadingCount > 0);
}
function ngxBlockLoading(params) {
    let loadingDirectives = getArray(params.blocking);
    return function (source) {
        return defer(() => {
            loadingDirectives.forEach(d => d.start());
            if (params.fullPage) {
                loadingCount++;
                updateFullPageLoading();
            }
            return source.pipe(finalize(() => {
                loadingDirectives.forEach(d => d.stop());
                if (params.fullPage) {
                    loadingCount--;
                    updateFullPageLoading();
                }
            }));
        });
    };
}

const NGX_BLOCK_LOADING_OPTIONS = new InjectionToken('NGX_BLOCK_LOADING_OPTIONS');
const DEFAULT_OPTIONS = {
    inTime: '0.25s',
    outTime: '0.25s',
    loaderOutTime: '0.25s',
    containerHeight: '100px',
    loadingContainerClass: 'ngx-block-loading--container',
    loadingClass: 'ngx-block-loading',
    loadingFullPageClass: 'ngx-block-loading__full-page'
};

class AnimationHelperService {
    constructor(animationBuilder) {
        this.animationBuilder = animationBuilder;
        this.hasLoadingElement = [];
        this.players = [];
        this.loadingElements = [];
    }
    elementRefEquals(one, two) {
        return one?.nativeElement.isSameNode(two?.nativeElement);
    }
    getPlayerWrapperIndex(element) {
        const playerWrapperIndex = this.players.findIndex(e => this.elementRefEquals(e.element, element));
        return playerWrapperIndex;
    }
    addPlayer(element, player) {
        if (!element) {
            return;
        }
        const playerWrapperIndex = this.getPlayerWrapperIndex(element);
        if (playerWrapperIndex === -1) {
            this.players.push({ element: element, players: [player] });
            return;
        }
        const playerWrapper = this.players[playerWrapperIndex];
        this.players[playerWrapperIndex] = {
            element: element,
            players: playerWrapper.players.concat(player)
        };
    }
    getPlayers(element) {
        const playerWrapperIndex = this.getPlayerWrapperIndex(element);
        if (playerWrapperIndex === -1) {
            return [];
        }
        const players = this.players[playerWrapperIndex].players;
        return players;
    }
    clearPlayers(element) {
        const playerWrapperIndex = this.getPlayerWrapperIndex(element);
        if (playerWrapperIndex === -1) {
            return;
        }
        this.players.splice(playerWrapperIndex, 1);
    }
    getLoadingElementIndex(element) {
        const loadingElementIndex = this.loadingElements.findIndex(e => this.elementRefEquals(e.element, element));
        return loadingElementIndex;
    }
    addLoadingElement(element, loadingElement) {
        if (!element) {
            return;
        }
        const loadingElementIndex = this.getLoadingElementIndex(element);
        if (loadingElementIndex === -1) {
            this.loadingElements.push({
                element: element,
                loadingElement: loadingElement
            });
        }
    }
    getLoadingElement(element) {
        if (!element) {
            return;
        }
        const loadingElementIndex = this.getLoadingElementIndex(element);
        if (loadingElementIndex === -1) {
            return undefined;
        }
        const loadingElement = this.loadingElements[loadingElementIndex].loadingElement;
        if (!loadingElement.nativeElement.parentNode) {
            loadingElement.nativeElement.parentNode = element.nativeElement;
        }
        return loadingElement;
    }
    removeLoadingElement(element) {
        const loadingElementIndex = this.getLoadingElementIndex(element);
        if (loadingElementIndex === -1) {
            return;
        }
        this.loadingElements.splice(loadingElementIndex, 1);
    }
    isElementLoading(element) {
        if (!element) {
            return false;
        }
        return this.hasLoadingElement.some(e => this.elementRefEquals(e, element));
    }
    runPlayer(element, metadata, destroyOnDone = false, onDone) {
        const factory = this.animationBuilder.build(useAnimation(metadata));
        const player = factory.create(element.nativeElement);
        const playerWrapper = {
            player: player,
            done: false
        };
        player.onDone(() => {
            playerWrapper.done = true;
            const players = this.getPlayers(element);
            if (destroyOnDone) {
                players.forEach(animationPlayer => {
                    this.tryRunMethodOnPlayer(() => animationPlayer.player.destroy());
                });
            }
            if (players.every(player => player.done)) {
                this.clearPlayers(element);
            }
            if (onDone) {
                onDone();
            }
        });
        player.play();
        this.addPlayer(element, playerWrapper);
    }
    isAnimationPlayerDone(player) {
        return (player.done ||
            player.player.totalTime === player.player.getPosition());
    }
    tryRunMethodOnPlayer(playerMethod, callbackIfFailed) {
        try {
            playerMethod();
        }
        catch (error) {
            // This error means that the player has been destroyed
            // However, Angular doesn't provide a means of checking if this has been done already
            // So we have to catch the error
            if (error &&
                error.message &&
                !error.message.includes('Unable to find the timeline player referenced by')) {
                throw error;
            }
            if (callbackIfFailed) {
                callbackIfFailed();
            }
        }
    }
    animate(element, metadata, destroyOnDone = false, onDone) {
        if (element) {
            const players = this.getPlayers(element);
            const notDonePlayers = players.filter(player => !this.isAnimationPlayerDone(player));
            if (notDonePlayers.length > 0) {
                const lastPlayerWrapper = notDonePlayers[notDonePlayers.length - 1];
                this.tryRunMethodOnPlayer(() => lastPlayerWrapper.player.onDone(() => {
                    this.runPlayer(element, metadata, destroyOnDone, onDone);
                }), () => {
                    this.runPlayer(element, metadata, destroyOnDone, onDone);
                });
            }
            else {
                this.runPlayer(element, metadata, destroyOnDone, onDone);
            }
        }
    }
    tryCreateLoadingElement(element, loadingElement, classes, styles, inTime, renderer, addLoadingClass) {
        if (!element || this.isElementLoading(element)) {
            return;
        }
        renderer.addClass(element.nativeElement, classes.container);
        renderer.appendChild(element.nativeElement, loadingElement.nativeElement);
        if (addLoadingClass) {
            renderer.addClass(loadingElement.nativeElement, classes.loading);
        }
        this.addLoadingElement(element, loadingElement);
        this.hasLoadingElement.push(element);
        this.animate(element, animation([
            styles.containerNotLoading,
            animate(inTime, styles.containerLoading)
        ]));
    }
    tryRemoveLoadingElement(element, classes, styles, times, renderer) {
        if (!element || !this.isElementLoading(element)) {
            return;
        }
        const loadingElement = this.getLoadingElement(element);
        const players = this.getPlayers(element);
        players.forEach(player => {
            if (!this.isAnimationPlayerDone(player)) {
                this.tryRunMethodOnPlayer(() => player.player.destroy());
            }
        });
        this.animate(element, animation([
            styles.loadingContainer,
            animate(times.outTime, style({
                height: element.nativeElement.scrollHeight
            }))
        ]), true, () => {
            const hasLoadingElementIndex = this.hasLoadingElement.findIndex(e => this.elementRefEquals(e, element));
            if (hasLoadingElementIndex > -1) {
                this.hasLoadingElement.splice(hasLoadingElementIndex, 1);
            }
            this.animate(loadingElement, animation([
                styles.loading,
                animate(times.loaderOutTime, styles.notLoading)
            ]), true, () => {
                if (loadingElement) {
                    renderer.removeChild(element.nativeElement, loadingElement.nativeElement);
                    this.removeLoadingElement(element);
                }
                else {
                    throw new Error('There is no element that was created for blocking, something has gone wrong.');
                }
                renderer.removeClass(element.nativeElement, classes.container);
            });
        });
    }
}
AnimationHelperService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: AnimationHelperService, deps: [{ token: i1.AnimationBuilder }], target: i0.ɵɵFactoryTarget.Injectable });
AnimationHelperService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: AnimationHelperService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: AnimationHelperService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.AnimationBuilder }]; } });

class NgxBlockLoadingFullPageComponent {
    constructor(options, animationHelper) {
        this.options = options;
        this.animationHelper = animationHelper;
        this.loading = false;
        this.onDestroy$ = new Subject();
        this.loaderOutTime = this.options.loaderOutTime;
        this.loadingClass = this.options.loadingClass;
        this.loadingFullPageClass = this.options.loadingFullPageClass;
        isLoadingFullPage
            .pipe(takeUntil(this.onDestroy$))
            .subscribe(loading => {
            if (this.isLoading == undefined) {
                this.updateLoading(loading);
            }
        });
    }
    get loadingStyle() {
        return style({
            visibility: 'visible',
            opacity: 1
        });
    }
    get notLoadingStyle() {
        return style({
            visibility: 'hidden',
            opacity: 0
        });
    }
    ngOnChanges(changes) {
        const loadingChanges = changes['loading'];
        if (loadingChanges) {
            this.updateLoading(loadingChanges.currentValue);
        }
    }
    updateLoading(loading) {
        if (loading) {
            this.loading = true;
        }
        else {
            this.removeFullPageLoading();
        }
    }
    removeFullPageLoading() {
        this.animationHelper.animate(this.element, animation([
            this.loadingStyle,
            animate(this.loaderOutTime, this.notLoadingStyle)
        ]), true, () => {
            this.loading = false;
        });
    }
}
NgxBlockLoadingFullPageComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingFullPageComponent, deps: [{ token: NGX_BLOCK_LOADING_OPTIONS }, { token: AnimationHelperService }], target: i0.ɵɵFactoryTarget.Component });
NgxBlockLoadingFullPageComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.2.5", type: NgxBlockLoadingFullPageComponent, selector: "ngx-block-loading-full-page", inputs: { template: "template", loaderOutTime: "loaderOutTime", loadingClass: "loadingClass", loadingFullPageClass: "loadingFullPageClass", isLoading: ["loading", "isLoading"] }, viewQueries: [{ propertyName: "element", first: true, predicate: ["element"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div #element>\n  <ng-container *ngIf=\"loading && template\">\n    <ng-container *ngTemplateOutlet=\"template\"></ng-container>\n  </ng-container>\n\n  <div class=\"{{loadingClass}} {{loadingFullPageClass}}\" *ngIf=\"loading && !template\"></div>\n</div>\n", styles: [""], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingFullPageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-block-loading-full-page', template: "<div #element>\n  <ng-container *ngIf=\"loading && template\">\n    <ng-container *ngTemplateOutlet=\"template\"></ng-container>\n  </ng-container>\n\n  <div class=\"{{loadingClass}} {{loadingFullPageClass}}\" *ngIf=\"loading && !template\"></div>\n</div>\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_BLOCK_LOADING_OPTIONS]
                }] }, { type: AnimationHelperService }]; }, propDecorators: { template: [{
                type: Input
            }], loaderOutTime: [{
                type: Input
            }], loadingClass: [{
                type: Input
            }], loadingFullPageClass: [{
                type: Input
            }], isLoading: [{
                type: Input,
                args: ['loading']
            }], element: [{
                type: ViewChild,
                args: ['element', { static: false }]
            }] } });

class BaseLoadingDirective {
    constructor(element, viewContainerRef, renderer, options, animationHelper) {
        this.element = element;
        this.viewContainerRef = viewContainerRef;
        this.renderer = renderer;
        this.options = options;
        this.animationHelper = animationHelper;
        this.onDestroy$ = new Subject();
        this.inTime = this.options.inTime;
        this.outTime = this.options.outTime;
        this.loaderOutTime = this.options.loaderOutTime;
        this.containerHeight = this.options.containerHeight;
        this.loadingContainerClass = this.options.loadingContainerClass;
        this.loadingClass = this.options.loadingClass;
    }
    get loadingContainerStyle() {
        return style({
            height: this.containerHeight
        });
    }
    get loadingStyle() {
        return style({
            visibility: 'visible',
            opacity: 1
        });
    }
    get notLoadingContainerStyle() {
        return style({
            height: this.element?.nativeElement?.scrollHeight || AUTO_STYLE
        });
    }
    get notLoadingStyle() {
        return style({
            visibility: 'hidden',
            opacity: 0
        });
    }
    ngOnDestroy() {
        this.onDestroy$.next();
        this.onDestroy$.complete();
    }
    start() {
        this.updateLoadingElement(true);
    }
    stop() {
        this.updateLoadingElement(false);
    }
    updateLoadingElement(isLoading) {
        if (isLoading) {
            this.animationHelper.tryCreateLoadingElement(this.elementToLoad, this.getLoadingElement(), {
                loading: this.loadingClass,
                container: this.loadingContainerClass
            }, {
                containerLoading: this.loadingContainerStyle,
                containerNotLoading: this.notLoadingContainerStyle
            }, this.inTime, this.renderer, this.template == undefined);
        }
        else {
            // Waiting a tick here because we need to let Angular finish rendering
            // It is likely that it actually hasn't
            setTimeout(() => this.animationHelper.tryRemoveLoadingElement(this.elementToLoad, {
                container: this.loadingContainerClass
            }, {
                loading: this.loadingStyle,
                loadingContainer: this.loadingContainerStyle,
                notLoading: this.notLoadingStyle
            }, {
                outTime: this.outTime,
                loaderOutTime: this.loaderOutTime
            }, this.renderer), 0);
        }
    }
    getTemplateElement() {
        this.viewContainerRef.clear();
        const viewRef = this.viewContainerRef.createEmbeddedView(this.template);
        const element = viewRef.rootNodes[0];
        const duplicatedElement = element.cloneNode(true);
        this.viewContainerRef.clear();
        return new ElementRef(duplicatedElement);
    }
    getLoadingElement() {
        let loadingElement;
        if (this.template) {
            loadingElement = this.getTemplateElement();
        }
        else {
            loadingElement = new ElementRef(this.renderer.createElement('div'));
        }
        return loadingElement;
    }
}
BaseLoadingDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: BaseLoadingDirective, deps: [{ token: i0.ElementRef }, { token: i0.ViewContainerRef }, { token: i0.Renderer2 }, { token: NGX_BLOCK_LOADING_OPTIONS }, { token: AnimationHelperService }], target: i0.ɵɵFactoryTarget.Directive });
BaseLoadingDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.5", type: BaseLoadingDirective, inputs: { inTime: "inTime", outTime: "outTime", loaderOutTime: "loaderOutTime", containerHeight: "containerHeight", loadingContainerClass: "loadingContainerClass", loadingClass: "loadingClass", template: "template" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: BaseLoadingDirective, decorators: [{
            type: Directive
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.ViewContainerRef }, { type: i0.Renderer2 }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_BLOCK_LOADING_OPTIONS]
                }] }, { type: AnimationHelperService }]; }, propDecorators: { inTime: [{
                type: Input
            }], outTime: [{
                type: Input
            }], loaderOutTime: [{
                type: Input
            }], containerHeight: [{
                type: Input
            }], loadingContainerClass: [{
                type: Input
            }], loadingClass: [{
                type: Input
            }], template: [{
                type: Input
            }] } });

class NgxBlockLoadingDirective extends BaseLoadingDirective {
    constructor(element, viewContainerRef, renderer, options, animationHelper) {
        super(element, viewContainerRef, renderer, options, animationHelper);
        this._isLoading = false;
        this.renderingDirectives = [];
    }
    set isLoading(value) {
        this._isLoading = value !== '' || value;
    }
    get isLoading() {
        return this._isLoading;
    }
    get elementToLoad() {
        return this.element;
    }
    ngOnChanges(changes) {
        const isLoadingChanges = changes['isLoading'];
        if (isLoadingChanges) {
            this.updateLoadingElement(isLoadingChanges.currentValue);
        }
    }
    getRenderingElementIndex(renderingDirective) {
        return this.renderingDirectives.findIndex(r => r.elementToLoad?.nativeElement.isSameNode(renderingDirective.elementToLoad?.nativeElement));
    }
    addRenderingElement(renderingDirective) {
        if (renderingDirective.elementToLoad?.nativeElement == undefined) {
            return;
        }
        const renderingElementIndex = this.getRenderingElementIndex(renderingDirective);
        if (renderingElementIndex === -1) {
            this.renderingDirectives.push(renderingDirective);
            if (!this.animationHelper.isElementLoading(this.elementToLoad)) {
                this.start();
            }
        }
    }
    removeRenderingElement(renderingDirective) {
        const renderingElementIndex = this.getRenderingElementIndex(renderingDirective);
        if (renderingElementIndex > -1) {
            this.renderingDirectives.splice(renderingElementIndex, 1);
        }
    }
    stop() {
        if (this.renderingDirectives.length === 0) {
            super.stop();
        }
    }
}
NgxBlockLoadingDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingDirective, deps: [{ token: i0.ElementRef }, { token: i0.ViewContainerRef }, { token: i0.Renderer2 }, { token: NGX_BLOCK_LOADING_OPTIONS }, { token: AnimationHelperService }], target: i0.ɵɵFactoryTarget.Directive });
NgxBlockLoadingDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.5", type: NgxBlockLoadingDirective, selector: "[ngxBlockLoading]", inputs: { isLoading: ["ngxBlockLoading", "isLoading"] }, exportAs: ["ngxBlockLoading"], usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxBlockLoading]',
                    exportAs: 'ngxBlockLoading'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.ViewContainerRef }, { type: i0.Renderer2 }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_BLOCK_LOADING_OPTIONS]
                }] }, { type: AnimationHelperService }]; }, propDecorators: { isLoading: [{
                type: Input,
                args: ['ngxBlockLoading']
            }] } });

class NgxBlockRenderingDirective extends BaseLoadingDirective {
    constructor() {
        super(...arguments);
        this._isRendering = true;
        this.startOnInit = true;
        this.forceStart = false;
    }
    set isRendering(value) {
        this._isRendering = value !== '' && value;
    }
    get isRendering() {
        return this._isRendering;
    }
    get elementToLoad() {
        if (this.element?.nativeElement.parentElement) {
            return new ElementRef(this.element?.nativeElement.parentElement);
        }
        return undefined;
    }
    ngOnInit() {
        if (this.startOnInit && this.isRendering && !this.loadingDirective) {
            this.start();
        }
        if (this.loadingDirective && this.isRendering) {
            this.loadingDirective.addRenderingElement(this);
        }
    }
    ngOnChanges(changes) {
        if (changes['isRendering'] && !this.isRendering) {
            if (this.loadingDirective) {
                this.loadingDirective.removeRenderingElement(this);
                this.loadingDirective.stop();
                return;
            }
            this.stop();
        }
        if (changes['forceStart'] && this.isRendering) {
            this.start();
        }
    }
}
NgxBlockRenderingDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockRenderingDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
NgxBlockRenderingDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.2.5", type: NgxBlockRenderingDirective, selector: "[ngxBlockRendering]", inputs: { isRendering: ["ngxBlockRendering", "isRendering"], startOnInit: "startOnInit", forceStart: "forceStart", loadingDirective: "loadingDirective" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockRenderingDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxBlockRendering]'
                }]
        }], propDecorators: { isRendering: [{
                type: Input,
                args: ['ngxBlockRendering']
            }], startOnInit: [{
                type: Input
            }], forceStart: [{
                type: Input
            }], loadingDirective: [{
                type: Input
            }] } });

class NgxBlockLoadingModule {
    static forRoot(options) {
        return {
            ngModule: NgxBlockLoadingModule,
            providers: [
                options?.provider || {
                    provide: NGX_BLOCK_LOADING_OPTIONS,
                    useValue: setDefaultOptions(options?.config)
                }
            ]
        };
    }
}
NgxBlockLoadingModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxBlockLoadingModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingModule, declarations: [NgxBlockLoadingDirective,
        NgxBlockRenderingDirective,
        NgxBlockLoadingFullPageComponent], imports: [CommonModule], exports: [NgxBlockLoadingDirective,
        NgxBlockRenderingDirective,
        NgxBlockLoadingFullPageComponent] });
NgxBlockLoadingModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.2.5", ngImport: i0, type: NgxBlockLoadingModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [
                        NgxBlockLoadingDirective,
                        NgxBlockRenderingDirective,
                        NgxBlockLoadingFullPageComponent
                    ],
                    exports: [
                        NgxBlockLoadingDirective,
                        NgxBlockRenderingDirective,
                        NgxBlockLoadingFullPageComponent
                    ]
                }]
        }] });
function setDefaultOptions(options) {
    const defaultOptions = DEFAULT_OPTIONS;
    return {
        loadingTemplate: options?.loadingTemplate || defaultOptions.loadingTemplate,
        inTime: options?.inTime || defaultOptions.inTime,
        outTime: options?.outTime || defaultOptions.outTime,
        loaderOutTime: options?.loaderOutTime || defaultOptions.loaderOutTime,
        containerHeight: options?.containerHeight || defaultOptions.containerHeight,
        loadingContainerClass: options?.loadingContainerClass ||
            defaultOptions.loadingContainerClass,
        loadingClass: options?.loadingClass || defaultOptions.loadingClass,
        loadingFullPageClass: options?.loadingFullPageClass || defaultOptions.loadingFullPageClass
    };
}

/*
 * Public API Surface of loading
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NGX_BLOCK_LOADING_OPTIONS, NgxBlockLoadingDirective, NgxBlockLoadingFullPageComponent, NgxBlockLoadingModule, NgxBlockRenderingDirective, ngxBlockLoading };
//# sourceMappingURL=ngx-block-loading.mjs.map
